@@ -28,8 +28,8 @@ def handle_exception(func, *args, **kwargs):
         result = func(*args, **kwargs)
     except Exception, e:
         traceback.print_exc()
-        return False, e
-    return True, result
+        return e
+    return result
 
 def runs_once(func):
     def decorator(*args, **kwargs):
@@ -72,7 +72,7 @@ def sudo(*args, **kwargs):
 def local(*args, **kwargs):
     return api.local(*args,**kwargs)
 
-@emit_exception(keyfunc=lambda key, value : value[0] if value is not None else value, ExceptionClass=RemoteExecutionException)
+@emit_exception(keyfunc=lambda key, value : isinstance(value, RemoteExecutionException), ExceptionClass=RemoteExecutionException)
 def execute(func, *args, **kwargs):
     handle_exception.__name__= func.__name__
     # host='host', hosts=['host','host'], password='password, passwords={'host':'password'}
@@ -133,7 +133,7 @@ def get(source, dest, use_sudo=False):
 
     tmp = uuid.uuid1()
     tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
-    tar(source, tmpsourcepath, local=False)
+    tar(source, tmpsourcepath, local_use=False)
 
     with settings(warn_only=True):
         api.get(tmpsourcepath, dest, use_sudo)
